@@ -9,8 +9,6 @@ class ES(Optimizer):
     This is the **base** (abstract) class for all ES classes. Please use any of its concrete subclasses to
     optimize the black-box problem at hand.
 
-    For interesting applications of ES, see e.g. `<>`_ for fluid dynamics and structural engineering.
-
     .. note:: Its three methods (`initialize`, `iterate`, `optimize`) should be implemented by its subclasses.
 
        `ES` are a well-established family of randomized population-based search algorithms, proposed originally by two
@@ -68,6 +66,8 @@ class ES(Optimizer):
 
     References
     ----------
+    https://homepages.fhv.at/hgb/downloads/ES-Is-Not-Gradient-Follower.pdf
+
     Ollivier, Y., Arnold, L., Auger, A. and Hansen, N., 2017.
     Information-geometric optimization algorithms: A unifying picture via invariance principles.
     Journal of Machine Learning Research, 18(18), pp.1-65.
